/* found-bg-slide_show.h - fade window background between two surfaces

   Copyright 2008, Red Hat, Inc.

   This file is part of the Fd Library.

   The Fd Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   The Fd Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with the Fd Library; see the file COPYING.LIB.  If not,
   write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.

   Author: Ray Strode <rstrode@redhat.com>
*/

#ifndef __FD_BG_SLIDE_SHOW_H__
#define __FD_BG_SLIDE_SHOW_H__

#include <gdk/gdk.h>

G_BEGIN_DECLS

#define FD_BG_TYPE_SLIDE_SHOW            (fd_bg_slide_show_get_type ())
#define FD_BG_SLIDE_SHOW(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), FD_BG_TYPE_SLIDE_SHOW, FdBGSlideShow))
#define FD_BG_SLIDE_SHOW_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass),  FD_BG_TYPE_SLIDE_SHOW, FdBGSlideShowClass))
#define FD_BG_IS_SLIDE_SHOW(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FD_BG_TYPE_SLIDE_SHOW))
#define FD_BG_IS_SLIDE_SHOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass),  FD_BG_TYPE_SLIDE_SHOW))
#define FD_BG_SLIDE_SHOW_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj),  FD_BG_TYPE_SLIDE_SHOW, FdBGSlideShowClass))

typedef struct _FdBGSlideShowPrivate FdBGSlideShowPrivate;
typedef struct _FdBGSlideShow FdBGSlideShow;
typedef struct _FdBGSlideShowClass FdBGSlideShowClass;

struct _FdBGSlideShow
{
	GObject parent_object;

	FdBGSlideShowPrivate *priv;
};

struct _FdBGSlideShowClass
{
	GObjectClass parent_class;
};

G_DEFINE_AUTOPTR_CLEANUP_FUNC(FdBGSlideShow, g_object_unref)

GType             fd_bg_slide_show_get_type (void);
FdBGSlideShow *fd_bg_slide_show_new (const char *filename);
gboolean          fd_bg_slide_show_load (FdBGSlideShow  *self,
                                            GError           **error);

void              fd_bg_slide_show_load_async (FdBGSlideShow    *self,
                                                  GCancellable        *cancellable,
                                                  GAsyncReadyCallback  callback,
                                                  gpointer             user_data);
gboolean          fd_bg_slide_show_get_slide (FdBGSlideShow *self,
                                                 int               frame_number,
                                                 int               width,
                                                 int               height,
                                                 gdouble          *progress,
                                                 double           *duration,
                                                 gboolean         *is_fixed,
                                                 const char      **file1,
                                                 const char      **file2);

void              fd_bg_slide_show_get_current_slide (FdBGSlideShow  *self,
                                                         int                width,
                                                         int                height,
                                                         gdouble           *progress,
                                                         double            *duration,
                                                         gboolean          *is_fixed,
                                                         const char       **file1,
                                                         const char       **file2);


double fd_bg_slide_show_get_start_time (FdBGSlideShow *self);
double fd_bg_slide_show_get_total_duration (FdBGSlideShow *self);
gboolean fd_bg_slide_show_get_has_multiple_sizes (FdBGSlideShow *self);
int  fd_bg_slide_show_get_num_slides (FdBGSlideShow *self);
G_END_DECLS

#endif
