/* found-bg.h - 

   Copyright 2007, Red Hat, Inc.

   This file is part of the Fd Library.

   The Fd Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.
   
   The Fd Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.
   
   You should have received a copy of the GNU Library General Public
   License along with the Fd Library; see the file COPYING.LIB.  If not,
   write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.

   Author: Soren Sandmann <sandmann@redhat.com>
*/

#ifndef __FD_BG_H__
#define __FD_BG_H__

#include <gdk/gdk.h>
#include <gio/gio.h>
#include <gdesktop-enums.h>
#include "fd-desktop-thumbnail.h"
#include "fd-bg-crossfade.h"

G_BEGIN_DECLS

#define FD_TYPE_BG            (fd_bg_get_type ())
#define FD_BG(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), FD_TYPE_BG, FdBG))
#define FD_BG_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass),  FD_TYPE_BG, FdBGClass))
#define FD_IS_BG(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FD_TYPE_BG))
#define FD_IS_BG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass),  FD_TYPE_BG))
#define FD_BG_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj),  FD_TYPE_BG, FdBGClass))

typedef struct _FdBG FdBG;
typedef struct _FdBGClass FdBGClass;

G_DEFINE_AUTOPTR_CLEANUP_FUNC(FdBG, g_object_unref)

GType            fd_bg_get_type              (void);
FdBG *        	 fd_bg_new                   (void);
void             fd_bg_load_from_preferences (FdBG               *bg,
						 GSettings             *settings);
void             fd_bg_save_to_preferences   (FdBG               *bg,
						 GSettings             *settings);
/* Setters */
void             fd_bg_set_filename          (FdBG               *bg,
						 const char            *filename);
void             fd_bg_set_placement         (FdBG               *bg,
						 GDesktopBackgroundStyle placement);
void             fd_bg_set_rgba              (FdBG               *bg,
						 GDesktopBackgroundShading type,
						 GdkRGBA               *primary,
						 GdkRGBA               *secondary);

/* Getters */
GDesktopBackgroundStyle fd_bg_get_placement  (FdBG               *bg);
void		 fd_bg_get_rgba              (FdBG               *bg,
						 GDesktopBackgroundShading *type,
						 GdkRGBA               *primary,
						 GdkRGBA               *secondary);
const gchar *    fd_bg_get_filename          (FdBG               *bg);

/* Drawing and thumbnailing */
void             fd_bg_draw                  (FdBG               *bg,
						 GdkPixbuf             *dest);
cairo_surface_t *fd_bg_create_surface        (FdBG               *bg,
						 GdkWindow             *window,
						 int                    width,
						 int                    height);
gboolean         fd_bg_get_image_size        (FdBG               *bg,
						 FdDesktopThumbnailFactory *factory,
                                                 int                    best_width,
                                                 int                    best_height,
						 int                   *width,
						 int                   *height);
GdkPixbuf *      fd_bg_create_thumbnail      (FdBG               *bg,
						 FdDesktopThumbnailFactory *factory,
						 GdkScreen             *screen,
						 int                    dest_width,
						 int                    dest_height);
gboolean         fd_bg_is_dark               (FdBG               *bg,
                                                 int                    dest_width,
						 int                    dest_height);
gboolean         fd_bg_has_multiple_sizes    (FdBG               *bg);
gboolean         fd_bg_changes_with_time     (FdBG               *bg);
GdkPixbuf *      fd_bg_create_frame_thumbnail (FdBG              *bg,
						 FdDesktopThumbnailFactory *factory,
						 GdkScreen             *screen,
						 int                    dest_width,
						 int                    dest_height,
						 int                    frame_num);

G_END_DECLS

#endif
