/*
 * found-thumbnail.h: Utilities for handling thumbnails
 *
 * Copyright (C) 2002 Red Hat, Inc.
 *
 * This file is part of the Fd Library.
 *
 * The Fd Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * The Fd Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with the Fd Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 *
 * Author: Alexander Larsson <alexl@redhat.com>
 */

#ifndef FD_DESKTOP_THUMBNAIL_H
#define FD_DESKTOP_THUMBNAIL_H

#include <glib.h>
#include <glib-object.h>
#include <time.h>
#include <gdk-pixbuf/gdk-pixbuf.h>

G_BEGIN_DECLS

typedef enum {
  FD_DESKTOP_THUMBNAIL_SIZE_NORMAL,
  FD_DESKTOP_THUMBNAIL_SIZE_LARGE
} FdDesktopThumbnailSize;

#define FD_DESKTOP_TYPE_THUMBNAIL_FACTORY		(fd_desktop_thumbnail_factory_get_type ())
#define FD_DESKTOP_THUMBNAIL_FACTORY(obj)	(G_TYPE_CHECK_INSTANCE_CAST ((obj), FD_DESKTOP_TYPE_THUMBNAIL_FACTORY, FdDesktopThumbnailFactory))
#define FD_DESKTOP_THUMBNAIL_FACTORY_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass), FD_DESKTOP_TYPE_THUMBNAIL_FACTORY, FdDesktopThumbnailFactoryClass))
#define FD_DESKTOP_IS_THUMBNAIL_FACTORY(obj)		(G_TYPE_INSTANCE_CHECK_TYPE ((obj), FD_DESKTOP_TYPE_THUMBNAIL_FACTORY))
#define FD_DESKTOP_IS_THUMBNAIL_FACTORY_CLASS(klass)	(G_TYPE_CLASS_CHECK_CLASS_TYPE ((klass), FD_DESKTOP_TYPE_THUMBNAIL_FACTORY))

typedef struct _FdDesktopThumbnailFactory        FdDesktopThumbnailFactory;
typedef struct _FdDesktopThumbnailFactoryClass   FdDesktopThumbnailFactoryClass;
typedef struct _FdDesktopThumbnailFactoryPrivate FdDesktopThumbnailFactoryPrivate;

struct _FdDesktopThumbnailFactory {
	GObject parent;

	FdDesktopThumbnailFactoryPrivate *priv;
};

struct _FdDesktopThumbnailFactoryClass {
	GObjectClass parent;
};

G_DEFINE_AUTOPTR_CLEANUP_FUNC(FdDesktopThumbnailFactory, g_object_unref)

GType                  fd_desktop_thumbnail_factory_get_type (void);
FdDesktopThumbnailFactory *fd_desktop_thumbnail_factory_new      (FdDesktopThumbnailSize     size);

char *                 fd_desktop_thumbnail_factory_lookup   (FdDesktopThumbnailFactory *factory,
								 const char            *uri,
								 time_t                 mtime);

gboolean               fd_desktop_thumbnail_factory_has_valid_failed_thumbnail (FdDesktopThumbnailFactory *factory,
										   const char            *uri,
										   time_t                 mtime);
gboolean               fd_desktop_thumbnail_factory_can_thumbnail (FdDesktopThumbnailFactory *factory,
								      const char            *uri,
								      const char            *mime_type,
								      time_t                 mtime);
GdkPixbuf *            fd_desktop_thumbnail_factory_generate_thumbnail (FdDesktopThumbnailFactory *factory,
									   const char            *uri,
									   const char            *mime_type);
void                   fd_desktop_thumbnail_factory_save_thumbnail (FdDesktopThumbnailFactory *factory,
								       GdkPixbuf             *thumbnail,
								       const char            *uri,
								       time_t                 original_mtime);
void                   fd_desktop_thumbnail_factory_create_failed_thumbnail (FdDesktopThumbnailFactory *factory,
										const char            *uri,
										time_t                 mtime);


/* Thumbnailing utils: */
gboolean   fd_desktop_thumbnail_is_valid          (GdkPixbuf          *pixbuf,
						      const char         *uri,
						      time_t              mtime);
char *     fd_desktop_thumbnail_path_for_uri      (const char         *uri,
						      FdDesktopThumbnailSize  size);

G_END_DECLS

#endif /* FD_DESKTOP_THUMBNAIL_H */
