/* -*- mode: C; c-file-style: "linux"; indent-tabs-mode: t -*-
 *
 * Adapted from found-session/found-session/gs-idle-monitor.h
 *
 * Copyright (C) 2012 Red Hat, Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: William Jon McCann <mccann@jhu.edu>
 */

#ifndef __FD_IDLE_MONITOR_H__
#define __FD_IDLE_MONITOR_H__

#include <glib-object.h>
#include <gdk/gdk.h>

G_BEGIN_DECLS

#define FD_TYPE_IDLE_MONITOR         (fd_idle_monitor_get_type ())
#define FD_IDLE_MONITOR(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), FD_TYPE_IDLE_MONITOR, FdIdleMonitor))
#define FD_IDLE_MONITOR_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), FD_TYPE_IDLE_MONITOR, FdIdleMonitorClass))
#define FD_IS_IDLE_MONITOR(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), FD_TYPE_IDLE_MONITOR))
#define FD_IS_IDLE_MONITOR_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), FD_TYPE_IDLE_MONITOR))
#define FD_IDLE_MONITOR_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), FD_TYPE_IDLE_MONITOR, FdIdleMonitorClass))

typedef struct _FdIdleMonitor FdIdleMonitor;
typedef struct _FdIdleMonitorClass FdIdleMonitorClass;
typedef struct _FdIdleMonitorPrivate FdIdleMonitorPrivate;

struct _FdIdleMonitor
{
        GObject                  parent;
        FdIdleMonitorPrivate *priv;
};

struct _FdIdleMonitorClass
{
        GObjectClass          parent_class;
};

G_DEFINE_AUTOPTR_CLEANUP_FUNC(FdIdleMonitor, g_object_unref)

typedef void (*FdIdleMonitorWatchFunc) (FdIdleMonitor      *monitor,
                                           guint                  id,
                                           gpointer               user_data);

GType              fd_idle_monitor_get_type     (void);

FdIdleMonitor * fd_idle_monitor_new          (void);

guint              fd_idle_monitor_add_idle_watch    (FdIdleMonitor         *monitor,
							 guint64                   interval_msec,
							 FdIdleMonitorWatchFunc callback,
							 gpointer                  user_data,
							 GDestroyNotify            notify);

guint              fd_idle_monitor_add_user_active_watch (FdIdleMonitor          *monitor,
							     FdIdleMonitorWatchFunc  callback,
							     gpointer		     user_data,
							     GDestroyNotify	     notify);

void               fd_idle_monitor_remove_watch (FdIdleMonitor         *monitor,
                                                    guint                     id);

guint64            fd_idle_monitor_get_idletime (FdIdleMonitor         *monitor);

G_END_DECLS

#endif /* __FD_IDLE_MONITOR_H__ */
