/* found-rr-config.h
 * -*- c-basic-offset: 4 -*-
 *
 * Copyright 2007, 2008, Red Hat, Inc.
 * Copyright 2010 Giovanni Campagna
 * 
 * This file is part of the Fd Library.
 * 
 * The Fd Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * The Fd Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 * 
 * You should have received a copy of the GNU Library General Public
 * License along with the Fd Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 * 
 * Author: Soren Sandmann <sandmann@redhat.com>
 */
#ifndef FD_RR_CONFIG_H
#define FD_RR_CONFIG_H

#include <glib.h>
#include <glib-object.h>
#include "fd-rr.h"

typedef struct _FdRROutputInfo FdRROutputInfo;
typedef struct _FdRROutputInfoClass FdRROutputInfoClass;
typedef struct _FdRROutputInfoPrivate FdRROutputInfoPrivate;

struct _FdRROutputInfo
{
    GObject parent;

    /*< private >*/
    FdRROutputInfoPrivate *priv;
};

struct _FdRROutputInfoClass
{
    GObjectClass parent_class;
};

#define FD_TYPE_RR_OUTPUT_INFO                  (fd_rr_output_info_get_type())
#define FD_RR_OUTPUT_INFO(obj)                  (G_TYPE_CHECK_INSTANCE_CAST ((obj), FD_TYPE_RR_OUTPUT_INFO, FdRROutputInfo))
#define FD_IS_RR_OUTPUT_INFO(obj)               (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FD_TYPE_RR_OUTPUT_INFO))
#define FD_RR_OUTPUT_INFO_CLASS(klass)          (G_TYPE_CHECK_CLASS_CAST ((klass), FD_TYPE_RR_OUTPUT_INFO, FdRROutputInfoClass))
#define FD_IS_RR_OUTPUT_INFO_CLASS(klass)       (G_TYPE_CHECK_CLASS_TYPE ((klass), FD_TYPE_RR_OUTPUT_INFO))
#define FD_RR_OUTPUT_INFO_GET_CLASS(obj)        (G_TYPE_INSTANCE_GET_CLASS ((obj), FD_TYPE_RR_OUTPUT_INFO, FdRROutputInfoClass))

G_DEFINE_AUTOPTR_CLEANUP_FUNC(FdRROutputInfo, g_object_unref)

GType fd_rr_output_info_get_type (void);

char *fd_rr_output_info_get_name (FdRROutputInfo *self);

gboolean fd_rr_output_info_is_active  (FdRROutputInfo *self);
void     fd_rr_output_info_set_active (FdRROutputInfo *self, gboolean active);

void fd_rr_output_info_get_geometry (FdRROutputInfo *self, int *x, int *y, int *width, int *height);
void fd_rr_output_info_set_geometry (FdRROutputInfo *self, int  x, int  y, int  width, int  height);

int  fd_rr_output_info_get_refresh_rate (FdRROutputInfo *self);
void fd_rr_output_info_set_refresh_rate (FdRROutputInfo *self, int rate);

FdRRRotation fd_rr_output_info_get_rotation (FdRROutputInfo *self);
void            fd_rr_output_info_set_rotation (FdRROutputInfo *self, FdRRRotation rotation);
gboolean        fd_rr_output_info_supports_rotation (FdRROutputInfo *self, FdRRRotation rotation);

gboolean fd_rr_output_info_is_connected     (FdRROutputInfo *self);
const char *fd_rr_output_info_get_vendor    (FdRROutputInfo *self);
const char *fd_rr_output_info_get_product   (FdRROutputInfo *self);
const char *fd_rr_output_info_get_serial    (FdRROutputInfo *self);
double   fd_rr_output_info_get_aspect_ratio (FdRROutputInfo *self);
char    *fd_rr_output_info_get_display_name (FdRROutputInfo *self);

gboolean fd_rr_output_info_get_primary (FdRROutputInfo *self);
void     fd_rr_output_info_set_primary (FdRROutputInfo *self, gboolean primary);

int fd_rr_output_info_get_preferred_width  (FdRROutputInfo *self);
int fd_rr_output_info_get_preferred_height (FdRROutputInfo *self);

gboolean fd_rr_output_info_get_underscanning (FdRROutputInfo *self);
void     fd_rr_output_info_set_underscanning (FdRROutputInfo *self, gboolean underscanning);

gboolean fd_rr_output_info_is_primary_tile (FdRROutputInfo *self);

typedef struct _FdRRConfig FdRRConfig;
typedef struct _FdRRConfigClass FdRRConfigClass;
typedef struct _FdRRConfigPrivate FdRRConfigPrivate;

struct _FdRRConfig
{
    GObject parent;

    /*< private >*/
    FdRRConfigPrivate *priv;
};

struct _FdRRConfigClass
{
    GObjectClass parent_class;
};

#define FD_TYPE_RR_CONFIG                  (fd_rr_config_get_type())
#define FD_RR_CONFIG(obj)                  (G_TYPE_CHECK_INSTANCE_CAST ((obj), FD_TYPE_RR_CONFIG, FdRRConfig))
#define FD_IS_RR_CONFIG(obj)               (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FD_TYPE_RR_CONFIG))
#define FD_RR_CONFIG_CLASS(klass)          (G_TYPE_CHECK_CLASS_CAST ((klass), FD_TYPE_RR_CONFIG, FdRRConfigClass))
#define FD_IS_RR_CONFIG_CLASS(klass)       (G_TYPE_CHECK_CLASS_TYPE ((klass), FD_TYPE_RR_CONFIG))
#define FD_RR_CONFIG_GET_CLASS(obj)        (G_TYPE_INSTANCE_GET_CLASS ((obj), FD_TYPE_RR_CONFIG, FdRRConfigClass))

G_DEFINE_AUTOPTR_CLEANUP_FUNC(FdRRConfig, g_object_unref)

GType               fd_rr_config_get_type     (void);

FdRRConfig      *fd_rr_config_new_current  (FdRRScreen  *screen,
						  GError        **error);
gboolean            fd_rr_config_load_current (FdRRConfig  *self,
						  GError        **error);
gboolean            fd_rr_config_match        (FdRRConfig  *config1,
						  FdRRConfig  *config2);
gboolean            fd_rr_config_equal	 (FdRRConfig  *config1,
						  FdRRConfig  *config2);
void                fd_rr_config_sanitize     (FdRRConfig  *configuration);
gboolean            fd_rr_config_ensure_primary (FdRRConfig  *configuration);

gboolean	    fd_rr_config_apply  (FdRRConfig  *configuration,
					    FdRRScreen  *screen,
					    GError        **error);
gboolean	    fd_rr_config_apply_persistent  (FdRRConfig  *configuration,
						       FdRRScreen  *screen,
						       GError        **error);

gboolean            fd_rr_config_applicable   (FdRRConfig  *configuration,
						  FdRRScreen  *screen,
						  GError        **error);

gboolean            fd_rr_config_get_clone    (FdRRConfig  *configuration);
void                fd_rr_config_set_clone    (FdRRConfig  *configuration, gboolean clone);
FdRROutputInfo **fd_rr_config_get_outputs  (FdRRConfig  *configuration);

#endif
