/* found-rr.h
 *
 * Copyright 2007, 2008, Red Hat, Inc.
 * 
 * This file is part of the Fd Library.
 * 
 * The Fd Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * The Fd Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 * 
 * You should have received a copy of the GNU Library General Public
 * License along with the Fd Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 * 
 * Author: Soren Sandmann <sandmann@redhat.com>
 */
#ifndef FD_RR_H
#define FD_RR_H

#include <glib.h>
#include <gdk/gdk.h>

typedef struct FdRRScreenPrivate FdRRScreenPrivate;
typedef struct FdRROutput FdRROutput;
typedef struct FdRRCrtc FdRRCrtc;
typedef struct FdRRMode FdRRMode;

typedef struct {
	GObject parent;

	FdRRScreenPrivate* priv;
} FdRRScreen;

typedef struct {
	GObjectClass parent_class;

        void (*changed)                (FdRRScreen *screen);
        void (*output_connected)       (FdRRScreen *screen, FdRROutput *output);
        void (*output_disconnected)    (FdRRScreen *screen, FdRROutput *output);
} FdRRScreenClass;

typedef enum
{
    FD_RR_ROTATION_NEXT =	0,
    FD_RR_ROTATION_0 =	(1 << 0),
    FD_RR_ROTATION_90 =	(1 << 1),
    FD_RR_ROTATION_180 =	(1 << 2),
    FD_RR_ROTATION_270 =	(1 << 3),
    FD_RR_REFLECT_X =	(1 << 4),
    FD_RR_REFLECT_Y =	(1 << 5)
} FdRRRotation;

typedef enum {
	FD_RR_DPMS_ON,
	FD_RR_DPMS_STANDBY,
	FD_RR_DPMS_SUSPEND,
	FD_RR_DPMS_OFF,
	FD_RR_DPMS_UNKNOWN
} FdRRDpmsMode;

/* Identical to drm_color_ctm from <drm_mode.h> */
typedef struct {
    /*
     * Conversion matrix in S31.32 sign-magnitude (not two's complement!)
     * format.
     */
    guint64 matrix[9];
} FdRRCTM;

/* Error codes */

#define FD_RR_ERROR (fd_rr_error_quark ())

GQuark fd_rr_error_quark (void);

typedef enum {
    FD_RR_ERROR_UNKNOWN,		/* generic "fail" */
    FD_RR_ERROR_NO_RANDR_EXTENSION,	/* RANDR extension is not present */
    FD_RR_ERROR_RANDR_ERROR,		/* generic/undescribed error from the underlying XRR API */
    FD_RR_ERROR_BOUNDS_ERROR,	/* requested bounds of a CRTC are outside the maximum size */
    FD_RR_ERROR_CRTC_ASSIGNMENT,	/* could not assign CRTCs to outputs */
    FD_RR_ERROR_NO_MATCHING_CONFIG,	/* none of the saved configurations matched the current configuration */
    FD_RR_ERROR_NO_DPMS_EXTENSION,	/* DPMS extension is not present */
} FdRRError;

#define FD_RR_CONNECTOR_TYPE_PANEL "Panel"  /* This is a built-in LCD */

#define FD_TYPE_RR_SCREEN                  (fd_rr_screen_get_type())
#define FD_RR_SCREEN(obj)                  (G_TYPE_CHECK_INSTANCE_CAST ((obj), FD_TYPE_RR_SCREEN, FdRRScreen))
#define FD_IS_RR_SCREEN(obj)               (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FD_TYPE_RR_SCREEN))
#define FD_RR_SCREEN_CLASS(klass)          (G_TYPE_CHECK_CLASS_CAST ((klass), FD_TYPE_RR_SCREEN, FdRRScreenClass))
#define FD_IS_RR_SCREEN_CLASS(klass)       (G_TYPE_CHECK_CLASS_TYPE ((klass), FD_TYPE_RR_SCREEN))
#define FD_RR_SCREEN_GET_CLASS(obj)        (G_TYPE_INSTANCE_GET_CLASS ((obj), FD_TYPE_RR_SCREEN, FdRRScreenClass))

#define FD_TYPE_RR_OUTPUT (fd_rr_output_get_type())
#define FD_TYPE_RR_CRTC   (fd_rr_crtc_get_type())
#define FD_TYPE_RR_MODE   (fd_rr_mode_get_type())
#define FD_TYPE_RR_DPMS_MODE (fd_rr_dpms_mode_get_type())

G_DEFINE_AUTOPTR_CLEANUP_FUNC(FdRRScreen, g_object_unref)

GType fd_rr_screen_get_type (void);
GType fd_rr_output_get_type (void);
GType fd_rr_crtc_get_type (void);
GType fd_rr_mode_get_type (void);
GType fd_rr_dpms_mode_get_type (void);

/* FdRRScreen */
FdRRScreen * fd_rr_screen_new                (GdkScreen             *screen,
						    GError               **error);
void            fd_rr_screen_new_async          (GdkScreen             *screen,
                                                    GAsyncReadyCallback    callback,
                                                    gpointer               user_data);
FdRRScreen * fd_rr_screen_new_finish         (GAsyncResult          *result,
                                                    GError               **error);
FdRROutput **fd_rr_screen_list_outputs       (FdRRScreen         *screen);
FdRRCrtc **  fd_rr_screen_list_crtcs         (FdRRScreen         *screen);
FdRRMode **  fd_rr_screen_list_modes         (FdRRScreen         *screen);
FdRRMode **  fd_rr_screen_list_clone_modes   (FdRRScreen	  *screen);
FdRRCrtc *   fd_rr_screen_get_crtc_by_id     (FdRRScreen         *screen,
						    guint32                id);
gboolean        fd_rr_screen_refresh            (FdRRScreen         *screen,
						    GError               **error);
FdRROutput * fd_rr_screen_get_output_by_id   (FdRRScreen         *screen,
						    guint32                id);
FdRROutput * fd_rr_screen_get_output_by_name (FdRRScreen         *screen,
						    const char            *name);
void            fd_rr_screen_get_ranges         (FdRRScreen         *screen,
						    int                   *min_width,
						    int                   *max_width,
						    int                   *min_height,
						    int                   *max_height);

gboolean        fd_rr_screen_get_dpms_mode      (FdRRScreen        *screen,
                                                    FdRRDpmsMode       *mode,
                                                    GError               **error);
gboolean        fd_rr_screen_set_dpms_mode      (FdRRScreen         *screen,
                                                    FdRRDpmsMode        mode,
                                                    GError              **error);

/* FdRROutput */
guint32         fd_rr_output_get_id             (FdRROutput         *output);
const char *    fd_rr_output_get_name           (FdRROutput         *output);
const char *    fd_rr_output_get_display_name   (FdRROutput         *output);
const guint8 *  fd_rr_output_get_edid_data      (FdRROutput         *output,
						    gsize                 *size);
void            fd_rr_output_get_ids_from_edid  (FdRROutput         *output,
                                                    char                 **vendor,
                                                    char                 **product,
                                                    char                 **serial);
void            fd_rr_output_get_physical_size  (FdRROutput         *output,
                                                    int                   *width_mm,
                                                    int                   *height_mm);

gint            fd_rr_output_get_backlight      (FdRROutput         *output);
gint            fd_rr_output_get_min_backlight_step(FdRROutput      *output);
gboolean        fd_rr_output_set_backlight      (FdRROutput         *output,
                                                gint                   value,
                                                GError                **error);
gboolean        fd_rr_output_set_color_transform(FdRROutput         *output,
                                                FdRRCTM             value,
                                                GError                **error);

FdRRCrtc **  fd_rr_output_get_possible_crtcs (FdRROutput         *output);
FdRRMode *   fd_rr_output_get_current_mode   (FdRROutput         *output);
FdRRCrtc *   fd_rr_output_get_crtc           (FdRROutput         *output);
gboolean        fd_rr_output_is_builtin_display (FdRROutput         *output);
void            fd_rr_output_get_position       (FdRROutput         *output,
						    int                   *x,
						    int                   *y);
gboolean        fd_rr_output_can_clone          (FdRROutput         *output,
						    FdRROutput         *clone);
FdRRMode **  fd_rr_output_list_modes         (FdRROutput         *output);
FdRRMode *   fd_rr_output_get_preferred_mode (FdRROutput         *output);
gboolean        fd_rr_output_supports_mode      (FdRROutput         *output,
						    FdRRMode           *mode);
gboolean        fd_rr_output_get_is_primary     (FdRROutput         *output);
gboolean        fd_rr_output_get_is_underscanning (FdRROutput       *output);
gboolean        fd_rr_output_supports_underscanning (FdRROutput       *output);
gboolean        fd_rr_output_supports_color_transform (const FdRROutput *output);

/* FdRRMode */
guint32         fd_rr_mode_get_id               (FdRRMode           *mode);
guint           fd_rr_mode_get_width            (FdRRMode           *mode);
guint           fd_rr_mode_get_height           (FdRRMode           *mode);
int             fd_rr_mode_get_freq             (FdRRMode           *mode);
double          fd_rr_mode_get_freq_f           (FdRRMode           *mode);
gboolean        fd_rr_mode_get_is_tiled         (FdRRMode           *mode);
gboolean        fd_rr_mode_get_is_interlaced    (FdRRMode           *mode);

/* FdRRCrtc */
guint32         fd_rr_crtc_get_id               (FdRRCrtc           *crtc);

gboolean        fd_rr_crtc_can_drive_output     (FdRRCrtc           *crtc,
						    FdRROutput         *output);
FdRRMode *   fd_rr_crtc_get_current_mode     (FdRRCrtc           *crtc);
void            fd_rr_crtc_get_position         (FdRRCrtc           *crtc,
						    int                   *x,
						    int                   *y);
FdRRRotation fd_rr_crtc_get_current_rotation (FdRRCrtc           *crtc);
FdRRRotation fd_rr_crtc_get_rotations        (FdRRCrtc           *crtc);
gboolean        fd_rr_crtc_supports_rotation    (FdRRCrtc           *crtc,
						    FdRRRotation        rotation);

gboolean        fd_rr_crtc_get_gamma            (FdRRCrtc           *crtc,
						    int                   *size,
						    unsigned short       **red,
						    unsigned short       **green,
						    unsigned short       **blue);
gboolean        fd_rr_crtc_set_gamma            (FdRRCrtc           *crtc,
						    int                    size,
						    unsigned short        *red,
						    unsigned short        *green,
						    unsigned short        *blue);

#endif /* FD_RR_H */
