#ifndef __FD_SESSION_H__
#define __FD_SESSION_H__

#include <glib-object.h>
#include <gio/gio.h>

G_BEGIN_DECLS

/**
 * Export from found-session::GsmInhibitorFlag.
 * It is used to function "fd_session_get_inhibited_actions".
 */
typedef enum {
        FSM_INHIBITOR_FLAG_LOGOUT      = 1 << 0,
        FSM_INHIBITOR_FLAG_SWITCH_USER = 1 << 1,
        FSM_INHIBITOR_FLAG_SUSPEND     = 1 << 2,
        FSM_INHIBITOR_FLAG_IDLE        = 1 << 3,
        FSM_INHIBITOR_FLAG_AUTOMOUNT   = 1 << 4
} FsmInhibitorFlag;

/**
 * Export from found-session::GsmPresenceStatus.
 * it is used to function "fd_session_presence_get_status",
 * or "fd_session_presence_set_status".
 */
typedef enum {
        FSM_PRESENCE_STATUS_AVAILABLE = 0,
        FSM_PRESENCE_STATUS_INVISIBLE,
        FSM_PRESENCE_STATUS_BUSY,
        FSM_PRESENCE_STATUS_IDLE,
} FsmPresenceStatus;

/* Presence Object */
#define FD_TYPE_SESSION_PRESENCE (fd_session_presence_get_type ())
G_DECLARE_FINAL_TYPE (FdSessionPresence, fd_session_presence, FD, SESSION_PRESENCE, GObject)

FdSessionPresence *
fd_session_presence_get_default (void);
guint32 
fd_session_presence_get_status (FdSessionPresence *presence);
gboolean 
fd_session_presence_set_status (FdSessionPresence *presence, guint32 status);

/* Inhibitor Objcet */
#define FD_TYPE_SESSION_INHIBITOR (fd_session_inhibitor_get_type ())
G_DECLARE_FINAL_TYPE (FdSessionInhibitor, fd_session_inhibitor, FD, SESSION_INHIBITOR, GObject)

FdSessionInhibitor *
fd_session_inhibitor_new (gchar *object_path);
gchar *
fd_session_inhibitor_get_app_id (FdSessionInhibitor *inhibitor);
gchar *
fd_session_inhibitor_get_reason (FdSessionInhibitor *inhibitor);

/* Session Object */
#define FD_TYPE_SESSION (fd_session_get_type ())
G_DECLARE_FINAL_TYPE (FdSession, fd_session, FD, SESSION, GObject)

FdSession *
fd_session_get_default (void);
gboolean
fd_session_is_active (FdSession *session);
gboolean 
fd_session_is_running (FdSession *session);
const gchar *
fd_session_get_session_name (FdSession *session);
void 
fd_session_logout (FdSession *session, guint mode);
void 
fd_session_shutdown (FdSession *session);
gboolean 
fd_session_can_shutdown (FdSession *session);
void 
fd_session_reboot (FdSession *session);
char **
fd_session_get_inhibitors (FdSession *session);
guint32 
fd_session_get_inhibited_actions (FdSession *session);

G_END_DECLS

#endif
