/* found-tz-monitor.h - fade window background between two surfaces

   Copyright 2008, Red Hat, Inc.
   Copyright 2011, Red Hat, Inc.

   This file is part of the Fd Library.

   The Fd Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   The Fd Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with the Fd Library; see the file COPYING.LIB.  If not,
   write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.

   Author: Colin Walters <walters@verbum.org>
*/

#ifndef __FD_WALL_CLOCK_H__
#define __FD_WALL_CLOCK_H__

#include <gio/gio.h>
#include <gdesktop-enums.h>

G_BEGIN_DECLS

#define FD_TYPE_WALL_CLOCK            (fd_wall_clock_get_type ())
#define FD_WALL_CLOCK(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), FD_TYPE_WALL_CLOCK, FdWallClock))
#define FD_WALL_CLOCK_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass),  FD_TYPE_WALL_CLOCK, FdWallClockClass))
#define FD_IS_WALL_CLOCK(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FD_TYPE_WALL_CLOCK))
#define FD_IS_WALL_CLOCK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass),  FD_TYPE_WALL_CLOCK))
#define FD_WALL_CLOCK_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj),  FD_TYPE_WALL_CLOCK, FdWallClockClass))

typedef struct _FdWallClockPrivate FdWallClockPrivate;
typedef struct _FdWallClock FdWallClock;
typedef struct _FdWallClockClass FdWallClockClass;

struct _FdWallClock
{
	GObject parent_object;

	FdWallClockPrivate *priv;
};

struct _FdWallClockClass
{
	GObjectClass parent_class;
};

G_DEFINE_AUTOPTR_CLEANUP_FUNC(FdWallClock, g_object_unref)

GType             fd_wall_clock_get_type      (void);

FdWallClock *  fd_wall_clock_new           (void);

const char *      fd_wall_clock_get_clock     (FdWallClock *clock);

GTimeZone *       fd_wall_clock_get_timezone  (FdWallClock *clock);

char *            fd_wall_clock_string_for_datetime (FdWallClock      *self,
							GDateTime           *now,
							GDesktopClockFormat  clock_format,
							gboolean             show_weekday,
							gboolean             show_full_date,
							gboolean             show_seconds);

G_END_DECLS

#endif
