/*
 * Copyright (C) 2012 Red Hat, Inc.
 *
 * Written by: Rui Matos <rmatos@redhat.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

#ifndef __FD_XKB_INFO_H__
#define __FD_XKB_INFO_H__

#include <stdio.h>
#include <glib-object.h>

G_BEGIN_DECLS

#define FD_TYPE_XKB_INFO            (fd_xkb_info_get_type ())
#define FD_XKB_INFO(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), FD_TYPE_XKB_INFO, FdXkbInfo))
#define FD_XKB_INFO_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass),  FD_TYPE_XKB_INFO, FdXkbInfoClass))
#define FD_IS_XKB_INFO(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FD_TYPE_XKB_INFO))
#define FD_IS_XKB_INFO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass),  FD_TYPE_XKB_INFO))
#define FD_XKB_INFO_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj),  FD_TYPE_XKB_INFO, FdXkbInfoClass))

typedef struct _FdXkbInfoPrivate FdXkbInfoPrivate;
typedef struct _FdXkbInfo FdXkbInfo;
typedef struct _FdXkbInfoClass FdXkbInfoClass;

struct _FdXkbInfo
{
  GObject parent_object;

  FdXkbInfoPrivate *priv;
};

struct _FdXkbInfoClass
{
  GObjectClass parent_class;
};

G_DEFINE_AUTOPTR_CLEANUP_FUNC(FdXkbInfo, g_object_unref)

GType           fd_xkb_info_get_type                         (void);
FdXkbInfo   *fd_xkb_info_new                              (void);
GList          *fd_xkb_info_get_all_layouts                  (FdXkbInfo *self);
gboolean        fd_xkb_info_get_layout_info                  (FdXkbInfo *self,
                                                                 const gchar  *id,
                                                                 const gchar **display_name,
                                                                 const gchar **short_name,
                                                                 const gchar **xkb_layout,
                                                                 const gchar **xkb_variant);
GList          *fd_xkb_info_get_all_option_groups            (FdXkbInfo *self);
const gchar    *fd_xkb_info_description_for_group            (FdXkbInfo *self,
                                                                 const gchar  *group_id);
GList          *fd_xkb_info_get_options_for_group            (FdXkbInfo *self,
                                                                 const gchar  *group_id);
const gchar    *fd_xkb_info_description_for_option           (FdXkbInfo *self,
                                                                 const gchar  *group_id,
                                                                 const gchar  *id);
GList          *fd_xkb_info_get_layouts_for_language         (FdXkbInfo *self,
                                                                 const gchar  *language_code);
GList          *fd_xkb_info_get_layouts_for_country          (FdXkbInfo *self,
                                                                 const gchar  *country_code);
GList          *fd_xkb_info_get_languages_for_layout         (FdXkbInfo *self,
                                                                 const gchar  *layout_id);

G_END_DECLS

#endif  /* __FD_XKB_INFO_H__ */
